client

package
v0.0.0-...-cd93eb8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 31, 2017 License: Apache-2.0 Imports: 8 Imported by: 1

Documentation

Overview

Copyright 2017 Delos Development Foundation and contributors. Licensed under the Apache License, Version 2.0. See the COPYING file at the root of this distribution or at http://www.apache.org/licenses/LICENSE-2.0

Copyright 2017 Delos Development Foundation and contributors. Licensed under the Apache License, Version 2.0. See the COPYING file at the root of this distribution or at http://www.apache.org/licenses/LICENSE-2.0

Copyright 2017 Delos Development Foundation and contributors. Licensed under the Apache License, Version 2.0. See the COPYING file at the root of this distribution or at http://www.apache.org/licenses/LICENSE-2.0

Index

Constants

This section is empty.

Variables

var (
	AccountCommands = cli.Command{
		Name:     "account",
		Usage:    "operations for account",
		Category: "Account",
		Subcommands: []cli.Command{
			{
				Name:     "add",
				Action:   addAccount,
				Usage:    "create a new account",
				Category: "Account",
			},
			{
				Name:   "getAccount",
				Action: getAccountAmount,
				Usage:  "create a new account",
				Flags: []cli.Flag{
					cli.StringFlag{
						Name:  "addr",
						Usage: "address",
					},
				},
			},
		},
	}
)
var (
	TxCommands = cli.Command{
		Name:     "tx",
		Usage:    "operations for transaction",
		Category: "Transaction",
		Subcommands: []cli.Command{
			{
				Name:   "send",
				Usage:  "send a transaction",
				Action: sendTx,
				Flags: []cli.Flag{
					cli.StringFlag{
						Name:  "addr",
						Usage: "address",
					},
					cli.StringFlag{
						Name:  "payload",
						Usage: "payload",
					},
					cli.StringFlag{
						Name:  "privKey",
						Usage: "privateKey",
					},
					cli.StringFlag{
						Name:  "dest",
						Usage: "destAddress",
					},
					cli.StringFlag{
						Name:  "amount",
						Usage: "amount",
					},
					cli.StringFlag{
						Name:  "chainid",
						Usage: "chainid",
					},
				},
			},
		},
	}
)

Functions

This section is empty.

Types

type TmResult

type TmResult struct {
	Amount int `json:"amount"`
}

Jump to